@@ -21,10 +21,8 @@
 #include <QString>
 #include "mailimporter_export.h"
 
-namespace MailImporter
-{
-namespace OtherMailerUtil
-{
+namespace MailImporter {
+namespace OtherMailerUtil {
 MAILIMPORTER_EXPORT QString trojitaDefaultPath();
 MAILIMPORTER_EXPORT QString gearyDefaultPath();
 }
